<?php

namespace Slim\Latte;

class LatteView extends \Slim\View
{
    /** @var array Default configuration, can be overwritten by constructor */
    private $config = array(
        'path' => '',
        'cache' => '',
        'extension' => '.latte',
        'configure_engine' => null
    );

    /** @var Latte\Engine */
    private $engine;

    /**
     * Create new Latte view.
     *
     * @param string $path Root template directory (without trailing slash)
     */
    public function __construct($config=null) {
        parent::__construct();
        $config && $this->config = array_merge($this->config, $config);

        $this->setTemplatesDirectory($this->config['path']);

        $this->engine = new \Latte\Engine;
        $this->engine->setTempDirectory($this->config['cache']);

        if (is_callable($this->config['configure_engine']))
            call_user_func($this->config['configure_engine'], $this->engine);
    }

    public function getTemplatePathname($file) {
        //return parent::getTemplatePathname($file . $this->config['extension']);
        return $this->config['path'] . '/' . $file . $this->config['extension'];
    }

    /**
     * Render view.
     *
     * @param string $template Template path (relative from root dir, without
     *                         extension)
     * @param array $data Optional additional data to pass to the template.
     * @return string The rendered template
     */
    public function render($template, $data=null) {
        $path = $this->getTemplatePathname($template);
        $data = array_merge($this->data->all(), (array)$data);
        return $this->engine->renderToString($path, $data);
    }
}
